==> ulyxex.0.0.6.with-tinyMce.zip: pages/code/admin.php <==
<?php
class Admin extends Ulyxex  {
	function __construct() {
		$this->h = New Html();
		$this->tr = New Translate();
	}
	public function version(){
		$dbLink = @mysql_connect(HOSTMYSQL,USERMYSQL,PASSMYSQL);
		$selectBase = @mysql_select_db(BASEMYSQL,$dbLink); 
		$version = mysql_get_server_info();
		@mysql_close($dbLink);
		return $version;
	}
	public function login($login,$password) {
		$query = "SELECT PASSWORD,USERLEVEL FROM ".USERS." WHERE LOGIN = '".$this->h->safe($login)."'";
		$query = $this->q($query);
		$dat = mysql_fetch_assoc($query);
		if ($dat['PASSWORD'] == $password) {
			return $dat['USERLEVEL'];
		} else {
			exit($this->tr->w("bad login & password"));
		}
	}
	public function user_id($login) {
		$query = "SELECT ID FROM ".USERS." WHERE LOGIN = '".$login."'";
		$query = $this->q($query);
		$dat = mysql_fetch_assoc($query);
		
		return $dat['ID'];
	}
	public function user_params($userId) {
		$query = "SELECT * FROM ".USERS." WHERE ID = ".$userId;
		$query = $this->q($query);
		$dat = mysql_fetch_assoc($query);
		return $dat;
	}
	public function totalItems($table) {
		$query = "SELECT COUNT(ID) AS NUM FROM ".$table;
		$query = $this->q($query);
		$result = mysql_fetch_assoc($query);
		return $result['NUM'];	
	}
	public function SelectUserPages($name,$catId) {
		$siteDat = $this->home_params();
		$queryLevel1 = 	"SELECT ID,NAME FROM ".PAGES." ORDER BY NAME";
		$queryLevel2 = 	"SELECT ".PAGES.".ID,".PAGES.".NAME FROM ".PAGES.",".USERPAGES.
						" WHERE ".USERPAGES.".USERID = ".$_SESSION['userid']." AND ".
						USERPAGES.".PAGEID = ".PAGES.".ID ".
						" ORDER BY ".PAGES.".NAME";
		
		$queryLevel3 = $queryLevel2;

		$queries = array("",$queryLevel1,$queryLevel2,$queryLevel3);
		$query = $this->q($queries[$_SESSION['level']]);
		
		$elements = array();
		while ( $line = mysql_fetch_assoc($query) ) {
			if ($line['ID'] == $siteDat['PAGEID']) {
				$elements[$line['NAME']." (home)"] = $line['ID'];
			} else {
				$elements[$line['NAME']] = $line['ID'];
			}
		}
		$elements[$this->catName($siteDat['SANDBOXID'])] = $siteDat['SANDBOXID'];
		$result = $this->h->select($elements,$name,$catId);
		return $result;
	}
	public function catName($catId) {
		$query = "SELECT NAME FROM ".PAGES." WHERE ID = ".$catId;
		$query = $this->q($query);
		$dat = mysql_fetch_assoc($query);
		return $dat['NAME'];
	}
}
class NextPages {
	function __construct($items,$action) {
		$this->h = new Html();
		$this->items = $items;
		$this->action = $action;
		$this->pos = isset($_GET['pg'])?$_GET['pg']:0;
	}
	public function numbers() {
		/* total pages */
		$pages = $this->items/ADMINITEMSBYPAGE; 
		$pages++;
		$result = "";
		if ($pages > 2) {
			for($i=1;$i < $pages;$i++) {
				$num = $i?strval($i):"0";
				if ($i == $this->pos) {
					$result .= "(".$this->h->ahref("admin.php?".$this->h->action."&amp;pg=".$num,$num).") ";
				} else {
					$result .= $this->h->ahref("admin.php?".$this->h->action."&amp;pg=".$num,$num)." ";
				}
			}
		}
		return $result;
	}
}
?>

==> ulyxex.0.0.7.with-tinyMce.zip: pages/code/admin.php <==
<?php
class Admin extends Ulyxex  {
	function __construct() {
		$this->h = New Html();
		$this->tr = New Translate();
	}
	public function version(){
		$dbLink = @mysql_connect(HOSTMYSQL,USERMYSQL,PASSMYSQL);
		$selectBase = @mysql_select_db(BASEMYSQL,$dbLink); 
		$version = mysql_get_server_info();
		@mysql_close($dbLink);
		return $version;
	}
	public function login($login,$password) {
		$query = "SELECT PASSWORD,USERLEVEL FROM ".USERS." WHERE LOGIN = '".$this->h->safe($login)."'";
		$query = $this->q($query);
		$dat = mysql_fetch_assoc($query);
		if ($dat['PASSWORD'] == $password) {
			return $dat['USERLEVEL'];
		} else {
			exit($this->tr->w("bad login & password"));
		}
	}
	public function user_id($login) {
		$query = "SELECT ID FROM ".USERS." WHERE LOGIN = '".$login."'";
		$query = $this->q($query);
		$dat = mysql_fetch_assoc($query);
		
		return $dat['ID'];
	}
	public function user_params($userId) {
		$query = "SELECT * FROM ".USERS." WHERE ID = ".$userId;
		$query = $this->q($query);
		$dat = mysql_fetch_assoc($query);
		return $dat;
	}
	public function totalItems($table) {
		$query = "SELECT COUNT(ID) AS NUM FROM ".$table;
		$query = $this->q($query);
		$result = mysql_fetch_assoc($query);
		return $result['NUM'];	
	}
	public function SelectUserPages($name,$catId) {
		$siteDat = $this->home_params();
		$queryLevel1 = 	"SELECT ID,NAME FROM ".PAGES." ORDER BY NAME";
		$queryLevel2 = 	"SELECT ".PAGES.".ID,".PAGES.".NAME FROM ".PAGES.",".USERPAGES.
						" WHERE ".USERPAGES.".USERID = ".$_SESSION['userid']." AND ".
						USERPAGES.".PAGEID = ".PAGES.".ID ".
						" ORDER BY ".PAGES.".NAME";
		
		$queryLevel3 = $queryLevel2;

		$queries = array("",$queryLevel1,$queryLevel2,$queryLevel3);
		$query = $this->q($queries[$_SESSION['level']]);
		
		$elements = array();
		while ( $line = mysql_fetch_assoc($query) ) {
			if ($line['ID'] == $siteDat['PAGEID']) {
				$elements[$line['NAME']." (home)"] = $line['ID'];
			} else {
				$elements[$line['NAME']] = $line['ID'];
			}
		}
		$elements[$this->catName($siteDat['SANDBOXID'])] = $siteDat['SANDBOXID'];
		$result = $this->h->select($elements,$name,$catId);
		return $result;
	}
	public function catName($catId) {
		$query = "SELECT NAME FROM ".PAGES." WHERE ID = ".$catId;
		$query = $this->q($query);
		$dat = mysql_fetch_assoc($query);
		return $dat['NAME'];
	}
}
class NextPages {
	function __construct($items,$action) {
		$this->h = new Html();
		$this->items = $items;
		$this->action = $action;
		$this->pos = isset($_GET['pg'])?$_GET['pg']:0;
	}
	public function numbers() {
		/* total pages */
		$pages = $this->items/ADMINITEMSBYPAGE; 
		$pages++;
		$result = "";
		if ($pages > 2) {
			for($i=1;$i < $pages;$i++) {
				$num = $i?strval($i):"0";
				if ($i == $this->pos) {
					$result .= "(".$this->h->ahref("admin.php?".$this->action."&amp;pg=".$num,$num).") ";
				} else {
					$result .= $this->h->ahref("admin.php?".$this->action."&amp;pg=".$num,$num)." ";
				}
			}
		}
		return $result;
	}
}
?>
